Transceiver52M: Add UHD device type checking

UHD device type was previously detected, but only categorized in
terms of bus type, USB or Ethernet, and sample rate capability.
With the number of supported device increasing, we can no longer
easily group devices since we need to handle more and more
device-specific peculiarities. Some of these factors are managed
internally by the UHD driver, but other factors (e.g. timing
offsets) are specific to a single device.

Start by maintaining an enumerated list of relevant device types
that we can use for applying device specific operations. Also
rename the USB/Ethernet grouping to transmit window type because
that's what it is.

enum uhd_dev_type {
        USRP1,
        USRP2,
        B100,
        NUM_USRP_TYPES,
};

Signed-off-by: Thomas Tsou <tom@tsou.cc>
diff --git a/Transceiver52M/radioInterface.h b/Transceiver52M/radioInterface.h
index 6e15a1f..3c58222 100644
--- a/Transceiver52M/radioInterface.h
+++ b/Transceiver52M/radioInterface.h
@@ -140,8 +140,8 @@
   /** set thread priority on current thread */
   void setPriority() { mRadio->setPriority(); }
 
-  /** get transport bus type of attached device */ 
-  enum RadioDevice::busType getBus() { return mRadio->getBus(); }
+  /** get transport window type of attached device */ 
+  enum RadioDevice::TxWindowType getWindowType() { return mRadio->getWindowType(); }
 
 protected: